| utilMWRtitle | R Documentation |
Format the title for analyze functions
utilMWRtitle(
param,
accdat = NULL,
sumfun = NULL,
site = NULL,
dtrng = NULL,
resultatt = NULL,
locgroup = NULL
)
param |
character string of the parameter to plot |
accdat |
optional |
sumfun |
optional character indicating one of |
site |
character string of sites to include |
dtrng |
character string of length two for the date ranges as YYYY-MM-DD |
resultatt |
character string of result attributes to plot |
locgroup |
character string of location groups to plot from the |
All arguments are optional except param, appropriate text strings are appended to the param argument for all other optional arguments indicating the level of filtering used in the plot and data summary if appropriate
A formatted character string used for the title in analysis plots
# no filters
utilMWRtitle(param = 'DO')
# filter by date only
utilMWRtitle(param = 'DO', dtrng = c('2021-05-01', '2021-07-31'))
# filter by all
utilMWRtitle(param = 'DO', site = 'test', dtrng = c('2021-05-01', '2021-07-31'),
resultatt = 'test', locgroup = 'test')
# title using summary
accpth <- system.file('extdata/ExampleDQOAccuracy.xlsx', package = 'MassWateR')
accdat <- readMWRacc(accpth, runchk = FALSE)
utilMWRtitle(param = 'DO', accdat = accdat, sumfun = 'auto', site = 'test',
dtrng = c('2021-05-01', '2021-07-31'), resultatt = 'test', locgroup = 'test')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.